@@ -20,7 +20,10 @@ You can consult the GNU General Public License on http://www.gnu.org/licenses/gp
 from ._version import VERSION, __ver__, __version__
 
 from .dcom import COM_SPEEDS, DComError
-from .common import DApi2Side, DApiException, REG_SIZE, REG_MAX_VALUE
+from .common import DApi2Side, DApiException, REG_SIZE, REG_MAX_VALUE, dateToWord, versionToStr, versionToWord,\
+        wordToVersion, wordToDate 
+    
+from .signal import DSignal
     
 from .dmsg import  MsgType, MsgReaderState,ACK_CHAR, NAK_CHAR, CRC_INITIAL,\
                         ReadRegMessage, ValueRegMessage, BaseMessage, MsgReader, WriteRegMessage, WrittenRegMessage,\
@@ -37,4 +40,5 @@ from .dcom import DSerial, DSocket, DComTracingDirection, TRACE_INGOING_RAW_FMT,
         TRACE_INERROR_COLOR, TRACE_OUTERROR_COLOR
         
 from .derror import *
+from .dboard import *
 
