@@ -3,10 +3,10 @@ import datetime as DT
 MAJOR_VERSION = 0
 '''Major version number'''
 
-MINOR_VERSION = 1
+MINOR_VERSION = 3
 '''Minor version number'''
 
-REVISION_VERSION = 6
+REVISION_VERSION = 2
 '''Revision version number'''
 
 VERSION = (MAJOR_VERSION,MINOR_VERSION,REVISION_VERSION)
@@ -18,5 +18,5 @@ __version__ = '{0:d}.{1:d}.{2:d}'.format(*VERSION)
 __ver__ = '{0:d}.{1:d}'.format(*VERSION)
 '''DAPI2 library DAPI2 short version (str)'''
 
-DATE = DT.date(2021, 7, 12)
-'''Rlease date'''
\ No newline at end of file
+DATE = DT.date(2022, 2, 7)
+'''Release date'''
\ No newline at end of file
