@@ -16,10 +16,8 @@ from .dreg import RegContainer, RegContainerReader, RegisterArray
 
 from .common import DApi2Side
 from . import _version 
-from enum import IntEnum
-from .common import dateToWord, versionToWord
-from .derror import DApiCommandError
-from dapi2.derror import DErrorsContainer
+from .common import dateToWord, versionToWord, DIntEnum
+from .derror import DApiCommandError, DErrorsContainer
 
 
 
@@ -32,7 +30,7 @@ class DApi2(object):
     '''
 
 
-    def __init__(self, dcom, regsfile=None, dev_mode=False, errorsfie=None):
+    def __init__(self, dcom, regsfile=None, dev_mode=False, errorsfile=None):
         '''Constructor'''
         self.log = logging.getLogger(self.__class__.__name__)
         self.log.debug('Initialize')
@@ -46,9 +44,9 @@ class DApi2(object):
         
         _ = RegContainerReader(container=self.regs, filename=regsfile)
         
-        if errorsfie is None:
-            errorsfie = os.path.join(os.path.dirname(__file__), 'errors.xml')        
-        self.derrors = DErrorsContainer(self, errorsfie) 
+        if errorsfile is None:
+            errorsfile = os.path.join(os.path.dirname(__file__), 'errors.xml')        
+        self.derrors = DErrorsContainer(self, errorsfile) 
         
         self.dcom = dcom
         self.dev_mode = dev_mode
@@ -177,7 +175,7 @@ class DApi2(object):
             
         
 
-class DApiAccessLevel(IntEnum):
+class DApiAccessLevel(DIntEnum):
     '''Enumeration for DAPI2 access level'''
     NO = 0
     '''No access or disconnected'''
@@ -200,7 +198,7 @@ class DApiAccessLevel(IntEnum):
 
     @property
     def help(self):
-        '''Help message according access level'''
+        '''Help message accordinDApiAccessLevelg access level'''
         return {
             self.NO : 'No access granted.',
             self.USER : 'Standard acces.',
@@ -218,6 +216,30 @@ class DApiAccessLevel(IntEnum):
             self.FACTORY : 0xf3f3,
             }[self]    
 
+
+class DApiAdditionalBoard(DIntEnum):
+    '''Enumeration for DAPI2 access level'''
+    NO = 0
+    AB12 = 1
+    AB03 = 2
+    
+    @property
+    def descr(self):
+        '''Label according access level'''
+        return {
+            self.NO : 'No',
+            self.AB12 : 'AB-12',
+            self.AB03 : 'AB-03',
+            }[self]    
+
+    @property
+    def help(self):
+        '''Help message according access level'''
+        return {
+            self.NO : 'No additional board is present.',
+            self.AB12 : 'Auxiliary inputs board (AB-12) is present.',
+            self.AB03 : 'Dual lighting (AB-03) is present.',
+            }[self]    
         
 class MetaDApi2Commands(object):
     NULL                  = 0x00
@@ -448,8 +470,8 @@ class DApi2Commands(MetaDApi2Commands):
         msg = self._sendCmd(msg)
         if self.owner.regs.smr.isUndefined():
             self.owner.readReg(self.owner.regs.smr)
-        self.owner.regs.smr.freewheel.set()
-        self.owner.regs.smr.start.clear()
+        self.owner.regs.smr.bits.freewheel.set()
+        self.owner.regs.smr.bits.start.clear()
         
 
     def motorStop(self):
@@ -457,8 +479,8 @@ class DApi2Commands(MetaDApi2Commands):
         msg = self._sendCmd(msg)
         if self.owner.regs.smr.isUndefined():
             self.owner.readReg(self.owner.regs.smr)
-        self.owner.regs.smr.freewheel.clear()
-        self.owner.regs.smr.start.clear()
+        self.owner.regs.smr.bits.freewheel.clear()
+        self.owner.regs.smr.bits.start.clear()
         
         
     def motorStart(self, speed=0):
@@ -467,7 +489,7 @@ class DApi2Commands(MetaDApi2Commands):
         msg = self._sendCmd(msg)
         if self.owner.regs.smr.isUndefined():
             self.owner.readReg(self.owner.regs.smr)
-        self.owner.regs.smr.start.set()
+        self.owner.regs.smr.bits.start.set()
         if speed != 0:
             self.owner.readReg(self.owner.regs.scr)
             #self.owner.regs.scr.value = speed
@@ -489,21 +511,21 @@ class DApi2Commands(MetaDApi2Commands):
         msg = self._sendCmd(msg)
         if self.owner.regs.smr.isUndefined():
             self.owner.readReg(self.owner.regs.smr)
-        self.owner.regs.smr.reverse.toggle()
+        self.owner.regs.smr.bits.reverse.toggle()
         
     def lightOff(self):
         msg = dmsg.CommandMessage(DApi2Commands.LIGHT_OFF)
         msg = self._sendCmd(msg)
         if self.owner.regs.smr.isUndefined():
             self.owner.readReg(self.owner.regs.smr)
-        self.owner.regs.smr.light.clear()
+        self.owner.regs.smr.bits.light.clear()
         
     def lightOn(self):
         msg = dmsg.CommandMessage(DApi2Commands.LIGHT_ON)
         msg = self._sendCmd(msg)
         if self.owner.regs.smr.isUndefined():
             self.owner.readReg(self.owner.regs.smr)
-        self.owner.regs.smr.light.set()
+        self.owner.regs.smr.bits.light.set()
 
     def lightIntensity(self, intensity):
         msg = dmsg.CommandMessage(DApi2Commands.LIGHT_INTENSITY)
@@ -537,7 +559,7 @@ class DApi2Commands(MetaDApi2Commands):
         msg.setByte(memory)
         msg.setByte(page)
         msg = self._sendCmd(msg)
-        return msg.getDataBytes()
+        return msg.getDataWords()
         
     def memoryReset(self):
         msg = dmsg.CommandMessage(DApi2Commands.MEMORY_RESET)
