@@ -1,9 +1,6 @@
 
-COM_SPEEDS = [115200, 57600, 38400, 19200, 9600]
-
-
 from .base import BaseDCom, RESPONSE_TIMEOUT, DComError, DComTracingDirection,\
         TRACE_INGOING_RAW_FMT, TRACE_OUTGOING_RAW_FMT, TRACE_INGOING_NORMAL_FMT, TRACE_OUTGOING_NORMAL_FMT,\
         TRACE_INGOING_COLOR, TRACE_OUTGOING_COLOR, TRACE_RESET_COLOR, TRACE_INERROR_COLOR, TRACE_OUTERROR_COLOR
-from .dserial import DSerial, DSerialState
+from .dserial import DSerial, DSerialState, COM_SPEEDS
 from .dsocket import DSocket
\ No newline at end of file
