@@ -180,12 +180,22 @@ class BaseMessage(object):
     def getDataBytes(self):
         '''Returns all data bytes.
         
-        :returm: The portion of the buffer that contains the data.
-        :rtype: 
+        :return: The portion of the buffer that contains the data.
+        :rtype: bytes
         '''
         
         return bytes(self._buffer[self.DATA0_IDX:-self.CRC_SIZE-1])
     
+    def getDataWords(self):
+        '''Returns all data as words array.
+        
+        :return: The portion of the buffer that contains the data.
+        :rtype: list of int (word)
+        '''
+        data = self.getDataBytes()
+        return list( [int.from_bytes(w,'big') for w in zip(data[0::2],data[1::2])]  )
+    
+    
     def getData(self, index, size=1):
         '''Returns a data value.
         
@@ -200,6 +210,15 @@ class BaseMessage(object):
         ''' 
         return int.from_bytes(self.getBytes(self.DATA0_IDX+index, size),'big') 
     
+    def getDataByte(self, index):
+        return self.getData(index, 1)
+    
+    def getDataWord(self, index):
+        return self.getData(index, 2)
+    
+    def getDataDWord(self, index):
+        return self.getData(index, 4)
+    
     def setData(self, value, index, size=1):
         assert value is not None
         if self.dataLen() < index+size:
