@@ -3,7 +3,7 @@
 :author: F. Voillat
 '''
 
-from .base import BaseRegElement, DRegException
+from .base import BaseRegElement, DRegException, DRegAccess
 from .container import RegContainer
 from .group import RegGroup
 from .register import Register, ReservedRegister, RegisterArray, BitFieldRegister, RegBit, RegBitChoice, ReservedRegBit
