@@ -4,15 +4,35 @@
 :date: 2021-01-17 Creation
 '''
 
+from enum import IntEnum
 
-
-from dapi2.common import DApiException
+from ..common import DApiException
+from ..signal import DSignal
 
 class DRegException(DApiException):
     '''Base class for register's module exceptions.'''
     pass
 
 
+class DRegAccess(IntEnum):
+    '''Enumeration of register access mode'''
+    
+    NO    = 0
+    READ  = 1
+    WRITE = 2
+    RW    = 3
+    
+class DRegChangedSignal(DSignal):
+    
+    def __init__(self, reg):
+        self._reg = reg
+        super().__init__(name='changed')
+        
+        
+    def emit(self, old):
+        for callback in self.callbacks:
+            callback(self._reg, old, self._reg.value)
+
 class BaseRegElement(object):
     '''Base class for registers structure elements.
     
