@@ -4,8 +4,6 @@
 :date: 2021-02-17 Creation
 '''
 from .. import dreg
-
-
         
 class RegGroup(dreg.BaseRegElement):
     '''Class for registers group in DAPI2 registers structure.
@@ -28,15 +26,15 @@ class RegGroup(dreg.BaseRegElement):
     :param shortname: Group short name (otional).
     :type shortname: str
 
-    :param readonly: Group readonly status (otional, default:True).
-    :type readonly: bool
+    :param access: Group access mode (otional, default:DRegAccess.READ).
+    :type readonly: DRegAccess
     '''
     
     
-    def __init__(self, name, parent=None, addr=None, size=0, descriptions=None, shortname=None, readonly=True, regs=[]):
+    def __init__(self, name, parent=None, addr=None, size=0, descriptions=None, shortname=None, access=dreg.DRegAccess.READ, regs=[]):
         assert parent is None or isinstance(parent, dreg.RegContainer), 'parent is '+type(parent).__name__
         super().__init__(name, parent=parent, addr=addr, size=size, descriptions=descriptions, shortname=shortname)
-        self.readonly = readonly  
+        self._access = access  
         self._regs = []
         
         for reg in regs:
@@ -105,12 +103,21 @@ class RegGroup(dreg.BaseRegElement):
             else:
                 raise TypeError('An object of class {0!s} cannot be added to the container.'.format(type(element).__name__))
             next_addr = element.addr+element.size
-            if next_addr > self._size:
-                self.setSize(next_addr)
+            if next_addr > self.addr + self._size:
+                self.setSize(next_addr-self.addr)
         return next_addr
     
+    @property
+    def values(self):
+        return self.container.values[self.addr:self.addr+self.size]
+    
     @property        
     def regs(self):
         '''The list of registers of the group.'''
         return self._regs
+    
+    @property
+    def access(self):
+        '''The group access mode'''
+        return self._access
     
\ No newline at end of file
