@@ -159,7 +159,7 @@ class RegGroupReader(BaseRegReader):
                         size=int(xgroup.get('size','0'),0), 
                         descriptions=getXmlDescriptions(xgroup),
                         shortname=xgroup.get('shortname'),
-                        readonly=not (int(xgroup.get('write','0')) == 1), 
+                        access=dreg.DRegAccess[xgroup.get('access','READ')], 
                     )
 
                     
@@ -202,16 +202,16 @@ class RegReader(BaseRegReader):
             raise ValueError('Size must be greater than 0') 
         
         try:
-            readonly = not (int(xreg.get('write')) == 1), 
+            access = dreg.DRegAccess[xreg.get('access')] 
         except:
-            readonly = self.parent.readonly
+            access  = self.parent.access
         self._element = _class( name,
                          self.parent, 
                          addr, 
                          size=size, 
                          descriptions=getXmlDescriptions(xreg),
                          shortname=xreg.get('shortname'),
-                         readonly=readonly,
+                         access =access ,
                          )
         
         if _class is dreg.BitFieldRegister:
