@@ -4,9 +4,10 @@ Created on 8 févr. 2021
 @author: fv
 '''
 
-from .base import BaseRegElement, DRegException
+from .base import BaseRegElement, DRegException, DRegAccess, DRegChangedSignal
 from .. import dreg
 from ..common import REG_MAX_VALUE  
+ 
 
 class DRegUndefinedError(DRegException):
     pass
@@ -32,20 +33,20 @@ class Register(BaseRegElement):
     :param shortname: Group short name (otional).
     :type shortname: str
 
-    :param readonly: Group readonly status (otional, default:True).
-    :type readonly: bool
+    :param access: Register access mode (default:DRegAccess.READ).
+    :type access: DRegAccess
     '''
     
     
-    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, min=0, max=REG_MAX_VALUE, readonly=True): #@ReservedAssignment
+    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, min=0, max=REG_MAX_VALUE, access=dreg.DRegAccess.READ): #@ReservedAssignment
         assert parent is None or isinstance(parent, (dreg.RegContainer, dreg.RegGroup, dreg.RegisterArray )), 'parent is '+type(parent).__name__
         super().__init__(name, parent, addr, size, descriptions, shortname)
-        self.readonly = readonly
+        self._access = access
         self.min = min
-        self.max = max  
+        self.max = max 
         self._modified = False
         self._undefined = True
-        self._callback_list = []
+        self._changed = DRegChangedSignal(self)
         
         
     def _stringData(self, lang=None):
@@ -60,14 +61,17 @@ class Register(BaseRegElement):
         
     def _valueChanged(self, old):
         if self.container.eventsEnabled:
-            for callback in self._callback_list:
-                callback(self, old, self.value)
+            self.changed.emit(old)
         
     def isModified(self):
         return self._modified
     
     def isUndefined(self):
         return self._undefined
+
+    def isDefined(self):
+        return not self._undefined
+
     
     def asString(self):
         return chr(self.value // 256) + chr( self.value & 0xff )  
@@ -78,46 +82,55 @@ class Register(BaseRegElement):
     def set(self, value, modified=False):
         self._undefined = False
         self._modified = modified
-        if self.container.values[self.addr] != value:
+        if self._undefined or (self.container.values[self.addr] != value):
             old = self.container.values[self.addr] 
             self.container.values[self.addr] = value
             self._valueChanged(old)
+            self._undefined = False
         
     def get(self):
         if self._undefined:
             raise DRegUndefinedError(self, 'get', 'Undefined value in register '+self.name)
         return self.container.values[self.addr]      
     
-    def connect(self, callback):
-        if all(x != callback for x in self._callback_list):
-            self._callback_list.append(callback)            
-
-    def disconnect(self, callback):
-        self._callback_list.remove(callback) 
+    # def connect(self, callback):
+    #     if all(x != callback for x in self._callback_list):
+    #         self._callback_list.append(callback)            
+    #
+    # def disconnect(self, callback):
+    #     self._callback_list.remove(callback) 
         
-
+    @property
+    def access(self):
+        '''The register access mode'''
+        return self._access
+    
+    @property
+    def changed(self):
+        return self._changed
         
 class ReservedRegister(Register):
     
         pass
 #     def get(self):
-#         raise  Exception('Get value of reserved register is not allowed!')     
-        
-class BitFieldRegister(Register):
+#         raise  Exception('Get value of reserved register is not allowed!') 
+
+
+class RegisterBits(object):
     
-    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, readonly=True):
-        super().__init__(name, parent, addr, size, descriptions, shortname, readonly)
+    def __init__(self, parent):
+        self._parent = parent
         self._bits = []
         self._index = {}
         
-    def __getitem__(self, index):
-        return self._bits[index]
-    
     def __getattr__(self, name):
         return self.getBit(name)
-    
+
     def __call__(self, name):
         return self.getBit(name)
+
+    def __getitem__(self, index):
+        return self._bits[index]
     
     def __len__(self):
         return len(self._bits)
@@ -125,12 +138,56 @@ class BitFieldRegister(Register):
     def __iter__(self):
         for bit in self._bits:
             yield bit         
+
         
     def _getNextFreeAddr(self):
         if len(self._bits)==0:
             return 0
         else:
             return self._bits[-1].addr + self._bits[-1].size
+
+    def add(self, *bits):
+        '''Adds bits to this bits field register
+        
+        :param bit: One or more bits to be added to the bits field register
+        :type bit: RegBit
+        
+        :return: The next address (position) after the last added bit
+        :rtype: int
+        '''
+        for bit in bits:
+            if bit.addr is None:
+                bit.setAddress(self._getNextFreeAddr())
+            self._bits.append(bit)
+            self._index[bit.name] = bit
+            
+            self._bits.sort(key=lambda x: x.addr)
+        return bit.addr+bit.size
+
+    
+    def getBit(self, name):
+        '''Returns the bit  according to its name.
+        
+        :param str name: the bit name to return
+        
+        :return: The bit found
+        :rtype: RegBit
+        '''
+        return self._index[name]
+
+        
+class BitFieldRegister(Register):
+    
+    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, access=DRegAccess.READ):
+        super().__init__(name, parent, addr, size, descriptions, shortname, access)
+        self._bits = RegisterBits(self)
+        
+    def __len__(self):
+        return len(self._bits)
+    
+    def __iter__(self):
+        for bit in self._bits:
+            yield bit         
         
     def _stringData(self, lang=None):
         try:
@@ -146,7 +203,7 @@ class BitFieldRegister(Register):
         :return: The bit found
         :rtype: RegBit
         '''
-        return self._index[name]
+        return self._bits.getBit(name)
         
         
     def toStringChildren(self, indent=1, prefix='', end='', depth=0, lang=None):
@@ -183,14 +240,7 @@ class BitFieldRegister(Register):
         :return: The next address (position) after the last added bit
         :rtype: int
         '''
-        for bit in bits:
-            if bit.addr is None:
-                bit.setAddress(self._getNextFreeAddr())
-            self._bits.append(bit)
-            self._index[bit.name] = bit
-            
-            self._bits.sort(key=lambda x: x.addr)
-        return bit.addr+bit.size
+        return self._bits.add(*bits)
     
     
     @property
@@ -198,12 +248,12 @@ class BitFieldRegister(Register):
         return self._bits 
         
 class RegisterArray(Register):
-    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, readonly=True):
-        super().__init__(name, parent, addr, size, descriptions, shortname, readonly)
+    def __init__(self, name, parent=None, addr=None, size=1, descriptions=None, shortname=None, access=dreg.DRegAccess.READ):
+        super().__init__(name, parent, addr, size, descriptions, shortname, access)
         self._regs = []
         
         for i in range(self.size):
-            reg = Register(self.name+str(i), self, self.addr+i, size=1, shortname=self.shortname+str(i), readonly=readonly)
+            reg = Register(self.name+str(i), self, self.addr+i, size=1, shortname=self.shortname+str(i), access=access)
             self._regs.append(reg)
 
     def __getitem__(self, index):
@@ -330,7 +380,11 @@ class RegBit(BaseRegElement):
         return self._parent.value
         
     def get(self):
-        return (self._parent.value & self._mask) >> self.addr  
+        return (self._parent.value & self._mask) >> self.addr
+    
+    @property
+    def mask(self):
+        return self._mask  
     
 class ReservedRegBit(RegBit):
     pass
